package com.huijy.management.service;

import java.util.List;
import com.huijy.management.domain.EarlyWarningSendLog;

/**
 * 预警信息发送日志Service接口
 *
 * @author luobo
 * @date 2021-10-04
 */
public interface IEarlyWarningSendLogService
{
    /**
     * 查询预警信息发送日志
     *
     * @param sendLogId 预警信息发送日志主键
     * @return 预警信息发送日志
     */
    public EarlyWarningSendLog selectEarlyWarningSendLogBySendLogId(Long sendLogId);

    /**
     * 查询预警信息发送日志列表
     *
     * @param earlyWarningSendLog 预警信息发送日志
     * @return 预警信息发送日志集合
     */
    public List<EarlyWarningSendLog> selectEarlyWarningSendLogList(EarlyWarningSendLog earlyWarningSendLog);

    /**
     * 新增预警信息发送日志
     *
     * @param earlyWarningSendLog 预警信息发送日志
     * @return 结果
     */
    public int insertEarlyWarningSendLog(EarlyWarningSendLog earlyWarningSendLog);

    /**
     * 修改预警信息发送日志
     *
     * @param earlyWarningSendLog 预警信息发送日志
     * @return 结果
     */
    public int updateEarlyWarningSendLog(EarlyWarningSendLog earlyWarningSendLog);

    /**
     * 批量删除预警信息发送日志
     *
     * @param sendLogIds 需要删除的预警信息发送日志主键集合
     * @return 结果
     */
    public int deleteEarlyWarningSendLogBySendLogIds(Long[] sendLogIds);

    /**
     * 删除预警信息发送日志信息
     *
     * @param sendLogId 预警信息发送日志主键
     * @return 结果
     */
    public int deleteEarlyWarningSendLogBySendLogId(Long sendLogId);

    /**
     * 根据msgId更新send_code
     * @param msgId
     * @param sendCode
     * @return
     */
    Integer updateLogByMsgId(String msgId,String sendCode);
}
